diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 8e17c075c64588266711b56f460bc9a22a6608b6..f67f9374944ec56015351ca8323f7c879692aa19 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,7 @@
+2000-11-12  Jakub Jelinek  <jakub@redhat.com>
+
+	* reload1.c (set_label_offsets): Go inside of PARALLELs.
+
 2000-11-12  Joseph S. Myers  <jsm28@cam.ac.uk>
 
 	* invoke.texi: Clean up option summary.
diff --git a/gcc/reload1.c b/gcc/reload1.c
index fe749293dbfa1586b3a2c2ea1c1ce18a4cb67b4d..5441494aa3db283ad0ee6c86568a85b700f6f44d 100644
--- a/gcc/reload1.c
+++ b/gcc/reload1.c
@@ -2089,11 +2089,12 @@ set_label_offsets (x, insn, initial_p)
 	  set_label_offsets (XEXP (tem, 0), insn, 1);
       return;
 
+    case PARALLEL:
     case ADDR_VEC:
     case ADDR_DIFF_VEC:
-      /* Each of the labels in the address vector must be at their initial
-	 offsets.  We want the first field for ADDR_VEC and the second
-	 field for ADDR_DIFF_VEC.  */
+      /* Each of the labels in the parallel or address vector must be
+	 at their initial offsets.  We want the first field for PARALLEL
+	 and ADDR_VEC and the second field for ADDR_DIFF_VEC.  */
 
       for (i = 0; i < (unsigned) XVECLEN (x, code == ADDR_DIFF_VEC); i++)
 	set_label_offsets (XVECEXP (x, code == ADDR_DIFF_VEC, i),